// Plot of voltage and current in a series resonant circuit
// Filename: ex2702.sce
// First set up values for time
t=(0:0.00001:0.01)'; // Plot range = 2 ms
clf(); // get rid of any earlier plot
// Set up circuit parameters
C = 1E-6;  // C = 1 uF
L = 0.22;  // L = 220 mH
R = 100;    // R = 100 ohm
// Get frequency to use
var = x_mdialog('Enter frequency','Frequency in Hz',['300']);
f = evstr(var(1));
// 
// Calculate the inductive reactance
xL = 2 * %pi * f * L;
// Calculate the capacitive reactance
xC = (2 * %pi * f * C)^-1;
// Calculate the impedance
z = sqrt(R^2 + (xL - xC)^2);
// Calculate the voltage dropped across each component when a  
// constant voltage of 2 V is applied to the circuit
i = 2 / z;
vl = i * xL * sin(2*%pi * f * t + %pi/2);
vc = i * xC * sin(2*%pi * f * t - %pi/2);
vr = i * R * sin(2*%pi * f * t);
// Plot the graphs of voltage against frequency
plot2d(t,vl,5,rect=[0,-10,0.01,10]); // plot in red
plot2d(t,vc,2,rect=[0,-10,0.01,10]); // plot in blue 
plot2d(t,vr,3,rect=[0,-10,0.01,10]); // plot in green
xtitle('Voltages in a series L-C-R circuit plotted against time','Time (s)','Voltage (V)');
legend(['vL','vC','vR']);

